@@ -212,7 +212,10 @@ def main():
                     results = dbLib.pkg_search(db, *pstr)
                     print_results(results)
                 elif len(pstr) == 3:
-                    results = dbLib.vendor_pkg_search(db, *pstr)
+                    index_hits = dbLib.bulk_index_search(
+                        [{"vendor": pstr[0], "name": pstr[1], "version": pstr[2]}]
+                    )
+                    results = dbLib.pkg_bulk_search(db, index_hits)
                     print_results(results)
                 else:
                     print("No vulnerability found!")
