@@ -33,6 +33,7 @@ except ImportError:
 json_lib = orjson if ORJSON_AVAILABLE else json
 
 threat_to_severity = {
+    "unspecified": "LOW",
     "": "LOW",
     "negligible": "LOW",
     "low": "LOW",
@@ -74,7 +75,7 @@ class AquaSource(NvdSource):
                             json_data = json_lib.loads(cve_data)
                             ret_data = self.convert(json_data)
                             self.store(ret_data, reindex=False)
-                        except Exception as e:
+                        except Exception:
                             pass
 
     def fetch(self, url):
@@ -84,7 +85,8 @@ class AquaSource(NvdSource):
             return self._process_zip(cached_zip)
         with CustomNamedTemporaryFile() as tf:
             try:
-                with httpx.stream("GET", url, follow_redirects=True) as r:
+                client = httpx.Client(http2=True, follow_redirects=True, timeout=180)
+                with client.stream("GET", url) as r:
                     for chunk in r.iter_bytes(chunk_size=download_chunk_size):
                         tf.write(chunk)
                     tf.flush()
@@ -132,7 +134,7 @@ class AquaSource(NvdSource):
         nvd_start_year = 2018
         try:
             nvd_start_year = int(config.nvd_start_year)
-        except:
+        except Exception:
             pass
         for year in range(1999, nvd_start_year):
             if f"CVE-{year}-" in zfname:
@@ -230,7 +232,7 @@ class AquaSource(NvdSource):
                 vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                 vuln.description = description
                 ret_data.append(vuln)
-            except Exception as e:
+            except Exception:
                 pass
         return ret_data
 
@@ -309,7 +311,7 @@ class AquaSource(NvdSource):
                     vuln.description = description
                     ret_data.append(vuln)
                     done_pkgs[pkg_key] = True
-                except Exception as e:
+                except Exception:
                     pass
         return ret_data
 
@@ -418,7 +420,7 @@ class AquaSource(NvdSource):
                             vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                             vuln.description = description
                             ret_data.append(vuln)
-                        except Exception as e:
+                        except Exception:
                             pass
         return ret_data
 
@@ -527,7 +529,7 @@ class AquaSource(NvdSource):
                     vuln.description = description
                     ret_data.append(vuln)
                     done_pkgs[pkg_key] = True
-                except Exception as e:
+                except Exception:
                     pass
         return ret_data
 
@@ -588,7 +590,7 @@ class AquaSource(NvdSource):
                     vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                     vuln.description = description
                     ret_data.append(vuln)
-                except Exception as e:
+                except Exception:
                     pass
         return ret_data
 
@@ -672,7 +674,7 @@ class AquaSource(NvdSource):
                             vuln.description = description
                             ret_data.append(vuln)
                             done_pkgs[pkg_key] = True
-                        except Exception as e:
+                        except Exception:
                             pass
         return ret_data
 
@@ -741,7 +743,7 @@ class AquaSource(NvdSource):
                 vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                 vuln.description = description
                 ret_data.append(vuln)
-            except Exception as e:
+            except Exception:
                 pass
         return ret_data
 
@@ -869,6 +871,6 @@ class AquaSource(NvdSource):
                     vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                     vuln.description = description
                     ret_data.append(vuln)
-                except Exception as e:
+                except Exception:
                     pass
         return ret_data
