@@ -79,7 +79,7 @@ class NvdSource(VulnerabilitySource):
         LOG.debug("Download NVD CVE from {}".format(url))
         with CustomNamedTemporaryFile() as tf:
             try:
-                with httpx.stream("GET", url, follow_redirects=True) as r:
+                with httpx.stream("GET", url, follow_redirects=True, timeout=180) as r:
                     for chunk in r.iter_bytes(chunk_size=download_chunk_size):
                         tf.write(chunk)
                     tf.flush()
