@@ -54,7 +54,8 @@ class ClassNotFoundError(Exception):
 
 def load(d):
     """Parses a python object from a JSON string. Every Object which should be loaded needs a constuctor that doesn't need any Arguments.
-    Arguments: Dict object; the module which contains the class, the parsed object is instance of."""
+    Arguments: Dict object; the module which contains the class, the parsed object is instance of.
+    """
 
     def _load(d):
         if isinstance(d, list):
@@ -1001,3 +1002,8 @@ def convert_score_severity(score):
             return "CRITICAL"
     except ValueError:
         return "LOW"
+
+
+def chunk_list(lst, size):
+    for i in range(0, len(lst), size):
+        yield lst[i : i + size]
